@@ -2,4 +2,4 @@ from starlite.connection.base import ASGIConnection, empty_receive, empty_send
 from starlite.connection.request import Request
 from starlite.connection.websocket import WebSocket
 
-__all__ = ["ASGIConnection", "Request", "WebSocket", "empty_receive", "empty_send"]
+__all__ = ("ASGIConnection", "Request", "WebSocket", "empty_receive", "empty_send")
