@@ -31,6 +31,17 @@ class Request(Generic[User, Auth], ASGIConnection["HTTPRouteHandler", User, Auth
     __slots__ = ("_json", "_form", "_body", "_content_type", "is_connected")
 
     scope: "HTTPScope"
+    """
+    The ASGI scope attached to the connection.
+    """
+    receive: "Receive"
+    """
+    The ASGI receive function.
+    """
+    send: "Send"
+    """
+    The ASGI send function.
+    """
 
     def __init__(self, scope: "Scope", receive: "Receive" = empty_receive, send: "Send" = empty_send) -> None:
         """The Starlite Request class.
