@@ -4,6 +4,7 @@ from .http_exceptions import (
     ImproperlyConfiguredException,
     InternalServerException,
     MethodNotAllowedException,
+    NoRouteMatchFoundException,
     NotAuthorizedException,
     NotFoundException,
     PermissionDeniedException,
@@ -22,6 +23,7 @@ __all__ = (
     "ValidationException",
     "NotAuthorizedException",
     "PermissionDeniedException",
+    "NoRouteMatchFoundException",
     "NotFoundException",
     "MethodNotAllowedException",
     "TooManyRequestsException",
