@@ -7,7 +7,6 @@ from typing import (
     Callable,
     Dict,
     List,
-    NoReturn,
     Optional,
     Type,
     Union,
@@ -407,11 +406,10 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         Returns:
             The default [Response][starlite.response.Response] class for the route handler.
         """
-        response_class = Response
-        for layer in self.ownership_layers:
+        for layer in list(reversed(self.ownership_layers)):
             if layer.response_class is not None:
-                response_class = layer.response_class
-        return response_class
+                return layer.response_class
+        return Response
 
     def resolve_response_headers(self) -> "ResponseHeadersMap":
         """Returns all header parameters in the scope of the handler function.
@@ -574,11 +572,11 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         if return_annotation is Signature.empty:
             raise ImproperlyConfiguredException(
                 "A return value of a route handler function should be type annotated."
-                "If your function doesn't return a value or returns None, annotate it as returning 'NoReturn' or 'None' respectively."
+                "If your function doesn't return a value, annotate it as returning 'None'."
             )
         if (
             self.status_code < 200 or self.status_code in {HTTP_204_NO_CONTENT, HTTP_304_NOT_MODIFIED}
-        ) and return_annotation not in {NoReturn, None}:
+        ) and return_annotation is not None:
             raise ImproperlyConfiguredException(
                 "A status code 204, 304 or in the range below 200 does not support a response body."
                 "If the function should return a value, change the route handler status code to an appropriate value.",
